# API Reference

```{eval-rst}
.. automodule:: zint
   :members:
   :undoc-members:
   :member-order: bysource

   .. attribute:: __version__

      Version of this package

   .. attribute:: __upstream_version__

      Version of the underlying C Zint implementation
```
